package String::Comments::Extract::C;

use strict;
use warnings;

use base qw/String::Comments::Extract::SlashStar/;

1;
